package com.ruoyi.web.controller.api;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.THospital;
import com.ruoyi.system.domain.TPatient;
import com.ruoyi.system.domain.TPatientHospitalDoctor;
import com.ruoyi.system.domain.TRecord;
import com.ruoyi.system.domain.req.AppPatientHospitalDoctor;
import com.ruoyi.system.domain.req.AppPatientReq;
import com.ruoyi.system.domain.req.AppRecordReq;
import com.ruoyi.system.domain.req.TRecordResultReq;
import com.ruoyi.system.domain.resp.TRecordResp;
import com.ruoyi.system.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author zhangcl
 * @date 2022/8/5 17:42
 */
@Api("app接口")
@RestController
@RequestMapping("/api/app")
public class AppController extends BaseController
{
    @Autowired
    private ITRecordService tRecordService;

    @Autowired
    private ITHospitalService tHospitalService;

    @Resource
    private ITDoctorService tDoctorService;

    @Resource
    private ITPatientService tPatientService;

    @Resource
    private ITPatientHospitalDoctorService itPatientHospitalDoctorService;

    @Resource
    private ISysConfigService configService;


    /**
     * 完成AI诊断
     */
    @ApiOperation("完成AI诊断")
    @GetMapping("/ai/finish")
    public AjaxResult finish(Long id)
    {
        TRecord record = tRecordService.selectTRecordById(id);
        if (record != null)
        {
            record.setStatus("1");
        }
        return toAjax(tRecordService.updateTRecord(record));

    }

    /**
     * 医院列表
     */
    @ApiOperation("医院列表")
    @GetMapping("/hospital/list")
    public AjaxResult hospitalList() {
        List<THospital> tHospitals = tHospitalService.selectTHospitalList(new THospital());
        return AjaxResult.success(tHospitals);
    }


    /**
     * 医生信息获取
     *
     * @param doctorId 医生id
     * @return {@code AjaxResult}
     */
    @ApiOperation("医生信息获取")
    @GetMapping("/doctor/info")
    public AjaxResult doctorInformation(Long doctorId)
    {
        return AjaxResult.success(tDoctorService.selectAppDoctorDetailById(doctorId));
    }

    /**
     * 患者预约
     *
     * @param appPatientHospitalDoctor 应用病人医院医生
     * @return {@code AjaxResult}
     */
    @ApiOperation("患者预约")
    @GetMapping("/patient/makeAnAppointment")
    public AjaxResult patientsToMakeAnAppointment(AppPatientHospitalDoctor appPatientHospitalDoctor)
    {
        // 患者预约，新增t_record中的一条记录;判断关联表是否存在当前关系
        TPatientHospitalDoctor tPatientHospitalDoctor = new TPatientHospitalDoctor();
        BeanUtils.copyProperties(appPatientHospitalDoctor, tPatientHospitalDoctor);
        tPatientHospitalDoctor.setPatientId(getUserId());
        TRecord tRecord = new TRecord();
        tRecord.setHospitalId(tPatientHospitalDoctor.getHospitalId());
        tRecord.setPatientId(tPatientHospitalDoctor.getPatientId());
        tRecord.setDoctorId(tPatientHospitalDoctor.getDoctorId());
        tRecord.setStatus("0");
        tRecord.setCreateBy(getUsername());
        tRecordService.insertTRecord(tRecord);
        List<TPatientHospitalDoctor> tPHDs = itPatientHospitalDoctorService.selectTPatientHospitalDoctorList(tPatientHospitalDoctor);
        if (tPHDs.isEmpty())
        {
            itPatientHospitalDoctorService.insertTPatientHospitalDoctor(tPatientHospitalDoctor);
        }
        return AjaxResult.success("预约成功");
    }

    @PutMapping("/record/ai/finish/{id}")
    @Log(title = "修改患者记录至已诊状态")
    public AjaxResult updateStatus(@PathVariable("id") Long id){
        if(id == null){
            return AjaxResult.error("未获取到记录id");
        }
        TRecord tRecord = new TRecord();
        tRecord.setId(id);
        tRecord.setStatus("1");
        tRecordService.updateTRecord(tRecord);
        return AjaxResult.success("更新状态成功",null);
    }

    @GetMapping(value = "/config/ai/refreshtime")
    @Log(title = "获取AI结果刷新时间接口")
    @ApiOperation("获取AI结果刷新时间接口")
    public AjaxResult getConfigKey()
    {
        String configKey="t.ai.refreshtime";
        return AjaxResult.success(configService.selectConfigByKey(configKey));
    }

    /**
     * 诊断记录上传
     *
     * @return {@code AjaxResult}
     */
    @ApiOperation("诊断记录上传")
    @PostMapping("/record/diagnostic/upload")
    public AjaxResult diagnosticRecordsUploaded(AppRecordReq appRecordReq) {
        TRecord tRecord = new TRecord();
        BeanUtils.copyProperties(appRecordReq, tRecord);
        return AjaxResult.success(tRecordService.updateTRecord(tRecord));
    }

    /**
     * 添加病人
     *
     * @param appPatientReq App端添加患者入参实体
     * @return {@code AjaxResult}
     */
    @ApiOperation("添加患者")
    @PostMapping("/patient/add")
    public AjaxResult addPatient(AppPatientReq appPatientReq)
    {
        TPatient tPatient = new TPatient();
        BeanUtils.copyProperties(appPatientReq, tPatient);
        tPatientService.insertTPatient(tPatient);
        TPatientHospitalDoctor tPatientHospitalDoctor = new TPatientHospitalDoctor();
        tPatientHospitalDoctor.setHospitalId(appPatientReq.getHospitalId());
        tPatientHospitalDoctor.setDoctorId(appPatientReq.getDoctorId());
        tPatientHospitalDoctor.setPatientId(appPatientReq.getId());
        List<TPatientHospitalDoctor> tPatientHospitalDoctors = itPatientHospitalDoctorService.selectTPatientHospitalDoctorList(tPatientHospitalDoctor);
        if (tPatientHospitalDoctors.isEmpty())
        {
            itPatientHospitalDoctorService.insertTPatientHospitalDoctor(tPatientHospitalDoctor);
        }
        return AjaxResult.success();
    }

    /**
     * 修改患者
     *
     * @param appPatientReq App端添加患者入参实体
     * @return {@code AjaxResult}
     */
    @ApiOperation("患者信息修改")
    @PostMapping("/patient/modify")
    public AjaxResult patientsWithModified(AppPatientReq appPatientReq) {
        TPatient tPatient = new TPatient();
        BeanUtils.copyProperties(appPatientReq, tPatient);
        return AjaxResult.success(tPatientService.updateTPatient(tPatient));
    }

    /**
     * 诊断记录列表
     *
     * @param appPatientHospitalDoctor 应用病人医院医生
     * @return {@code AjaxResult}
     */
    @ApiOperation("诊断记录列表")
    @GetMapping("/record/list")
    public AjaxResult diagnosisOfRecordList(AppPatientHospitalDoctor appPatientHospitalDoctor) {
        TPatientHospitalDoctor tPatientHospitalDoctor = new TPatientHospitalDoctor();
        BeanUtils.copyProperties(appPatientHospitalDoctor, tPatientHospitalDoctor);
        List<TRecordResp> tRecords = tRecordService.queryRecordListByPHDids(tPatientHospitalDoctor);
        return AjaxResult.success(tRecords);
    }

    /**
     * 患者诊断记录信息细节
     *
     * @param id id
     * @return {@code AjaxResult}
     */
    @ApiOperation("患者诊断记录信息详情")
    @GetMapping("/record/info/{id}")
    public AjaxResult patientsWithDiagnosisOfRecordInformationDetails(@PathVariable("id") Long id) {
        return AjaxResult.success(tRecordService.selectById(id));
    }

    /**
     * 患者已诊列表
     *
     * @param recordResultReq 记录结果要求
     * @return {@code AjaxResult}
     */
    @ApiOperation("患者已诊列表")
    @GetMapping("/record/diagnosedList")
    public AjaxResult patientsDiagnosedList(TRecordResultReq recordResultReq) {
        recordResultReq.setStatus("1");
        return AjaxResult.success(tRecordService.selectTRecordListWithoutResult(recordResultReq));
    }

    /**
     * 病人等待名单
     *
     * @param recordResultReq 记录结果要求
     * @return {@code AjaxResult}
     */
    @ApiOperation("患者候诊列表")
    @GetMapping("/record/waitingList")
    public AjaxResult patientsWaitingList(TRecordResultReq recordResultReq) {
        recordResultReq.setStatus("0");
        return AjaxResult.success(tRecordService.selectTRecordListWithoutResult(recordResultReq));
    }

    @ApiOperation("获取患者详细信息")
    @GetMapping ("/patient/info")
    public AjaxResult getPatientInfo() {
        return AjaxResult.success(tPatientService.selectTPatientById(getUserId()));
    }

}
