package com.ruoyi.web.controller.pc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.req.PcTDoctorQueryByPageReq;
import com.ruoyi.system.domain.req.PcTPatintQueryByPageReq;
import com.ruoyi.system.domain.resp.PcTPatientQueryByPageResp;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TPatient;
import com.ruoyi.system.service.ITPatientService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 患者信息Controller
 * 
 * @author ruoyi
 * @date 2022-08-03
 */
@Api("pc-患者列表")
@RestController
@RequestMapping("/system/patient")
public class TPatientController extends BaseController
{
    @Autowired
    private ITPatientService tPatientService;

    /**
     * 查询患者信息列表
     */
    @ApiOperation("查询患者信息列表")
    @PostMapping("/queryByPage")
    public TableDataInfo queryByPage(@RequestBody @Validated PcTPatintQueryByPageReq pcTPatintQueryByPageReq)
    {
        startPage();
        List<PcTPatientQueryByPageResp> list = tPatientService.queryByPage(pcTPatintQueryByPageReq);
        return getDataTable(list);
    }

    /**
     * 导出患者信息列表
     */
    @ApiOperation("导出患者信息列表")
    @Log(title = "患者信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TPatient tPatient)
    {
        List<TPatient> list = tPatientService.selectTPatientList(tPatient);
        ExcelUtil<TPatient> util = new ExcelUtil<TPatient>(TPatient.class);
        util.exportExcel(response, list, "患者信息数据");
    }

    /**
     * 获取患者信息详细信息
     */
    @ApiOperation("获取患者信息详细信息")
    @GetMapping(value = "/queryById/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tPatientService.selectTPatientById(id));
    }

    /**
     * 修改患者信息
     */
    @ApiOperation("修改患者信息")
    @Log(title = "患者信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TPatient tPatient)
    {
        return toAjax(tPatientService.updateTPatient(tPatient));
    }

    /**
     * 删除患者信息
     */
    @ApiOperation("删除患者信息")
    @Log(title = "患者信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/deleteById/{id}")
    public AjaxResult remove(@PathVariable("id") Long id)
    {
        return toAjax(tPatientService.deleteTPatientById(id));
    }
}
