package com.ruoyi.web.controller.pc;

import java.util.*;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.req.AppRecordReq;
import com.ruoyi.system.domain.req.TRecordResultReq;
import com.ruoyi.system.domain.resp.RecordHistoryDataResp;
import com.ruoyi.system.domain.resp.TRecordResp;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TRecord;
import com.ruoyi.system.service.ITRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 诊断记录信息Controller
 *
 * @author ruoyi
 * @date 2022-08-03
 */
@Api("pc-就诊记录")
@RestController
@RequestMapping("/system/record")
public class TRecordController extends BaseController
{
    @Autowired
    private ITRecordService tRecordService;

    /**
     * 查询诊断记录信息列表
     */
    @ApiOperation("查询就诊记录列表")
    @GetMapping("/list")
    public TableDataInfo list(TRecordResultReq tRecord)
    {
        startPage();
        List<TRecordResp> list = tRecordService.selectTRecordListWithoutResult(tRecord);
        return getDataTable(list);
    }

    /**
     * 导出诊断记录信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:export')")
    @Log(title = "诊断记录信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TRecord tRecord)
    {
        List<TRecord> list = tRecordService.selectTRecordList(tRecord);
        ExcelUtil<TRecord> util = new ExcelUtil<TRecord>(TRecord.class);
        util.exportExcel(response, list, "诊断记录信息数据");
    }

    /**
     * 获取诊断记录信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tRecordService.selectTRecordById(id));
    }

    /**
     * 新增诊断记录信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:add')")
    @Log(title = "诊断记录信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TRecord tRecord)
    {
        return toAjax(tRecordService.insertTRecord(tRecord));
    }

    /**
     * 修改诊断记录信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:edit')")
    @Log(title = "诊断记录信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TRecord tRecord)
    {
        return toAjax(tRecordService.updateTRecord(tRecord));
    }

    /**
     * 删除诊断记录信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:remove')")
    @Log(title = "诊断记录信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tRecordService.deleteTRecordByIds(ids));
    }

    @GetMapping("getInfo/{id}")
    @ApiOperation("查询患者诊断记录信息")
    public AjaxResult getInfoById(@PathVariable("id") Long id){
        if(id == null){
            return AjaxResult.error("未获取到id");
        }
        return AjaxResult.success(tRecordService.selectById(id));
    }

    @GetMapping("getHistoryRecordList")
    @ApiOperation("查询患者历史数据图表")
    public AjaxResult getHistoryRecordList(TRecord tRecord){
        return tRecordService.getHistoryList(tRecord);
    }


    /**
     * 诊断记录上传
     *
     * @return {@code AjaxResult}
     */
    @ApiOperation("诊断记录上传")
    @PostMapping("diagnostic/upload")
    public AjaxResult diagnosticRecordsUploaded(AppRecordReq appRecordReq) {
        TRecord tRecord = new TRecord();
        BeanUtils.copyProperties(appRecordReq, tRecord);
        return AjaxResult.success(tRecordService.updateTRecord(tRecord));
    }
}
